@@ -114,12 +114,6 @@ class JobShortcutsManager(GenericJob):
         self.options: dict = self.validate_options(options)
 
         # profile folder
-        if opersys not in OS_CONFIG:
-            raise OSError(
-                f"Your operating system {opersys} is not supported. "
-                f"Supported platforms: {','.join(OS_CONFIG.keys())}."
-            )
-
         self.os_config = OS_CONFIG.get(opersys)
         self.qdt_working_folder = get_qdt_working_directory()
         self.qgis_profiles_path: Path = Path(self.os_config.profiles_path)
@@ -168,43 +162,6 @@ class JobShortcutsManager(GenericJob):
             raise NotImplementedError
 
     # -- INTERNAL LOGIC ------------------------------------------------------
-
-    def filter_profiles_folder(self) -> tuple[QdtProfile]:
-        """Parse downloaded folder to filter on QGIS profiles folders.
-
-        Returns:
-            tuple[QdtProfile]: tuple of profiles objects
-        """
-        # first, try to get folders containing a profile.json
-        qgis_profiles_folder = [
-            QdtProfile.from_json(profile_json_path=f, profile_folder=f.parent)
-            for f in self.qdt_working_folder.glob("**/profile.json")
-        ]
-        if len(qgis_profiles_folder):
-            logger.debug(
-                f"{len(qgis_profiles_folder)} profiles found within {self.qdt_working_folder}"
-            )
-            return tuple(qgis_profiles_folder)
-
-        # if empty, try to identify if a folder is a QGIS profile - but unsure
-        for d in self.qdt_working_folder.glob("**"):
-            if (
-                d.is_dir()
-                and d.parent.name == "profiles"
-                and not d.name.startswith(".")
-            ):
-                qgis_profiles_folder.append(QdtProfile(folder=d, name=d.name))
-
-        if len(qgis_profiles_folder):
-            return tuple(qgis_profiles_folder)
-
-        # if still empty, raise a warning but returns every folder under a `profiles` folder
-        # TODO: try to identify if a folder is a QGIS profile with some approximate criteria
-
-        if not len(qgis_profiles_folder):
-            logger.error("No QGIS profile found in the downloaded folder.")
-            return None
-
     def get_matching_profile_from_name(
         self, li_profiles: list[QdtProfile], profile_name: str
     ) -> QdtProfile:
